# coding: utf-8

"""
    DeviceServer

    DeviceServer API  # noqa: E501

    The version of the OpenAPI document: 1.1.5
    Contact: david@3adesign.co.uk
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from DeviceServer.configuration import Configuration


class DevicePort(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'port_index': 'int',
        'label': 'str',
        'state_index': 'int',
        'state_count': 'int',
        'port_id': 'str',
        'state_label': 'str'
    }

    attribute_map = {
        'port_index': 'port_index',
        'label': 'label',
        'state_index': 'state_index',
        'state_count': 'state_count',
        'port_id': 'port_id',
        'state_label': 'state_label'
    }

    def __init__(self, port_index=None, label=None, state_index=None, state_count=None, port_id=None, state_label=None, local_vars_configuration=None):  # noqa: E501
        """DevicePort - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._port_index = None
        self._label = None
        self._state_index = None
        self._state_count = None
        self._port_id = None
        self._state_label = None
        self.discriminator = None

        self.port_index = port_index
        if label is not None:
            self.label = label
        if state_index is not None:
            self.state_index = state_index
        if state_count is not None:
            self.state_count = state_count
        self.port_id = port_id
        if state_label is not None:
            self.state_label = state_label

    @property
    def port_index(self):
        """Gets the port_index of this DevicePort.  # noqa: E501


        :return: The port_index of this DevicePort.  # noqa: E501
        :rtype: int
        """
        return self._port_index

    @port_index.setter
    def port_index(self, port_index):
        """Sets the port_index of this DevicePort.


        :param port_index: The port_index of this DevicePort.  # noqa: E501
        :type port_index: int
        """
        if self.local_vars_configuration.client_side_validation and port_index is None:  # noqa: E501
            raise ValueError("Invalid value for `port_index`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                port_index is not None and port_index > 100):  # noqa: E501
            raise ValueError("Invalid value for `port_index`, must be a value less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                port_index is not None and port_index < 1):  # noqa: E501
            raise ValueError("Invalid value for `port_index`, must be a value greater than or equal to `1`")  # noqa: E501

        self._port_index = port_index

    @property
    def label(self):
        """Gets the label of this DevicePort.  # noqa: E501


        :return: The label of this DevicePort.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this DevicePort.


        :param label: The label of this DevicePort.  # noqa: E501
        :type label: str
        """
        if (self.local_vars_configuration.client_side_validation and
                label is not None and len(label) > 64):
            raise ValueError("Invalid value for `label`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                label is not None and len(label) < 1):
            raise ValueError("Invalid value for `label`, length must be greater than or equal to `1`")  # noqa: E501

        self._label = label

    @property
    def state_index(self):
        """Gets the state_index of this DevicePort.  # noqa: E501


        :return: The state_index of this DevicePort.  # noqa: E501
        :rtype: int
        """
        return self._state_index

    @state_index.setter
    def state_index(self, state_index):
        """Sets the state_index of this DevicePort.


        :param state_index: The state_index of this DevicePort.  # noqa: E501
        :type state_index: int
        """
        if (self.local_vars_configuration.client_side_validation and
                state_index is not None and state_index < 0):  # noqa: E501
            raise ValueError("Invalid value for `state_index`, must be a value greater than or equal to `0`")  # noqa: E501

        self._state_index = state_index

    @property
    def state_count(self):
        """Gets the state_count of this DevicePort.  # noqa: E501


        :return: The state_count of this DevicePort.  # noqa: E501
        :rtype: int
        """
        return self._state_count

    @state_count.setter
    def state_count(self, state_count):
        """Sets the state_count of this DevicePort.


        :param state_count: The state_count of this DevicePort.  # noqa: E501
        :type state_count: int
        """
        if (self.local_vars_configuration.client_side_validation and
                state_count is not None and state_count < 1):  # noqa: E501
            raise ValueError("Invalid value for `state_count`, must be a value greater than or equal to `1`")  # noqa: E501

        self._state_count = state_count

    @property
    def port_id(self):
        """Gets the port_id of this DevicePort.  # noqa: E501


        :return: The port_id of this DevicePort.  # noqa: E501
        :rtype: str
        """
        return self._port_id

    @port_id.setter
    def port_id(self, port_id):
        """Sets the port_id of this DevicePort.


        :param port_id: The port_id of this DevicePort.  # noqa: E501
        :type port_id: str
        """
        if self.local_vars_configuration.client_side_validation and port_id is None:  # noqa: E501
            raise ValueError("Invalid value for `port_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                port_id is not None and len(port_id) > 36):
            raise ValueError("Invalid value for `port_id`, length must be less than or equal to `36`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                port_id is not None and len(port_id) < 36):
            raise ValueError("Invalid value for `port_id`, length must be greater than or equal to `36`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                port_id is not None and not re.search(r'[0-9a-f]{8}-[0-9a-f]{4}-4[0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}', port_id)):  # noqa: E501
            raise ValueError(r"Invalid value for `port_id`, must be a follow pattern or equal to `/[0-9a-f]{8}-[0-9a-f]{4}-4[0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}/`")  # noqa: E501

        self._port_id = port_id

    @property
    def state_label(self):
        """Gets the state_label of this DevicePort.  # noqa: E501


        :return: The state_label of this DevicePort.  # noqa: E501
        :rtype: str
        """
        return self._state_label

    @state_label.setter
    def state_label(self, state_label):
        """Sets the state_label of this DevicePort.


        :param state_label: The state_label of this DevicePort.  # noqa: E501
        :type state_label: str
        """
        if (self.local_vars_configuration.client_side_validation and
                state_label is not None and len(state_label) > 64):
            raise ValueError("Invalid value for `state_label`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                state_label is not None and len(state_label) < 1):
            raise ValueError("Invalid value for `state_label`, length must be greater than or equal to `1`")  # noqa: E501

        self._state_label = state_label

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DevicePort):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DevicePort):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    DeviceServer

    DeviceServer API  # noqa: E501

    The version of the OpenAPI document: 1.1.5
    Contact: david@3adesign.co.uk
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from DeviceServer.configuration import Configuration


class DeviceTxBuffer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'message_id': 'str',
        'timestamp': 'int',
        'device_message': 'str',
        'device_id': 'str',
        'device_serial': 'str',
        'device_type': 'str'
    }

    attribute_map = {
        'message_id': 'message_id',
        'timestamp': 'timestamp',
        'device_message': 'device_message',
        'device_id': 'device_id',
        'device_serial': 'device_serial',
        'device_type': 'device_type'
    }

    def __init__(self, message_id=None, timestamp=None, device_message=None, device_id=None, device_serial=None, device_type=None, local_vars_configuration=None):  # noqa: E501
        """DeviceTxBuffer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._message_id = None
        self._timestamp = None
        self._device_message = None
        self._device_id = None
        self._device_serial = None
        self._device_type = None
        self.discriminator = None

        self.message_id = message_id
        if timestamp is not None:
            self.timestamp = timestamp
        if device_message is not None:
            self.device_message = device_message
        if device_id is not None:
            self.device_id = device_id
        if device_serial is not None:
            self.device_serial = device_serial
        if device_type is not None:
            self.device_type = device_type

    @property
    def message_id(self):
        """Gets the message_id of this DeviceTxBuffer.  # noqa: E501


        :return: The message_id of this DeviceTxBuffer.  # noqa: E501
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """Sets the message_id of this DeviceTxBuffer.


        :param message_id: The message_id of this DeviceTxBuffer.  # noqa: E501
        :type message_id: str
        """
        if self.local_vars_configuration.client_side_validation and message_id is None:  # noqa: E501
            raise ValueError("Invalid value for `message_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                message_id is not None and len(message_id) > 100):
            raise ValueError("Invalid value for `message_id`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                message_id is not None and len(message_id) < 1):
            raise ValueError("Invalid value for `message_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._message_id = message_id

    @property
    def timestamp(self):
        """Gets the timestamp of this DeviceTxBuffer.  # noqa: E501


        :return: The timestamp of this DeviceTxBuffer.  # noqa: E501
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this DeviceTxBuffer.


        :param timestamp: The timestamp of this DeviceTxBuffer.  # noqa: E501
        :type timestamp: int
        """

        self._timestamp = timestamp

    @property
    def device_message(self):
        """Gets the device_message of this DeviceTxBuffer.  # noqa: E501


        :return: The device_message of this DeviceTxBuffer.  # noqa: E501
        :rtype: str
        """
        return self._device_message

    @device_message.setter
    def device_message(self, device_message):
        """Sets the device_message of this DeviceTxBuffer.


        :param device_message: The device_message of this DeviceTxBuffer.  # noqa: E501
        :type device_message: str
        """
        if (self.local_vars_configuration.client_side_validation and
                device_message is not None and len(device_message) > 100):
            raise ValueError("Invalid value for `device_message`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                device_message is not None and len(device_message) < 1):
            raise ValueError("Invalid value for `device_message`, length must be greater than or equal to `1`")  # noqa: E501

        self._device_message = device_message

    @property
    def device_id(self):
        """Gets the device_id of this DeviceTxBuffer.  # noqa: E501


        :return: The device_id of this DeviceTxBuffer.  # noqa: E501
        :rtype: str
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this DeviceTxBuffer.


        :param device_id: The device_id of this DeviceTxBuffer.  # noqa: E501
        :type device_id: str
        """
        if (self.local_vars_configuration.client_side_validation and
                device_id is not None and len(device_id) > 36):
            raise ValueError("Invalid value for `device_id`, length must be less than or equal to `36`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                device_id is not None and len(device_id) < 36):
            raise ValueError("Invalid value for `device_id`, length must be greater than or equal to `36`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                device_id is not None and not re.search(r'[0-9a-f]{8}-[0-9a-f]{4}-4[0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}', device_id)):  # noqa: E501
            raise ValueError(r"Invalid value for `device_id`, must be a follow pattern or equal to `/[0-9a-f]{8}-[0-9a-f]{4}-4[0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}/`")  # noqa: E501

        self._device_id = device_id

    @property
    def device_serial(self):
        """Gets the device_serial of this DeviceTxBuffer.  # noqa: E501


        :return: The device_serial of this DeviceTxBuffer.  # noqa: E501
        :rtype: str
        """
        return self._device_serial

    @device_serial.setter
    def device_serial(self, device_serial):
        """Sets the device_serial of this DeviceTxBuffer.


        :param device_serial: The device_serial of this DeviceTxBuffer.  # noqa: E501
        :type device_serial: str
        """
        if (self.local_vars_configuration.client_side_validation and
                device_serial is not None and len(device_serial) > 32):
            raise ValueError("Invalid value for `device_serial`, length must be less than or equal to `32`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                device_serial is not None and len(device_serial) < 1):
            raise ValueError("Invalid value for `device_serial`, length must be greater than or equal to `1`")  # noqa: E501

        self._device_serial = device_serial

    @property
    def device_type(self):
        """Gets the device_type of this DeviceTxBuffer.  # noqa: E501


        :return: The device_type of this DeviceTxBuffer.  # noqa: E501
        :rtype: str
        """
        return self._device_type

    @device_type.setter
    def device_type(self, device_type):
        """Sets the device_type of this DeviceTxBuffer.


        :param device_type: The device_type of this DeviceTxBuffer.  # noqa: E501
        :type device_type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                device_type is not None and len(device_type) > 100):
            raise ValueError("Invalid value for `device_type`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                device_type is not None and len(device_type) < 1):
            raise ValueError("Invalid value for `device_type`, length must be greater than or equal to `1`")  # noqa: E501

        self._device_type = device_type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceTxBuffer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeviceTxBuffer):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    DeviceServer

    DeviceServer API  # noqa: E501

    The version of the OpenAPI document: 1.1.5
    Contact: david@3adesign.co.uk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from DeviceServer.models.db_button_state import DbButtonState
from DeviceServer.models.db_device_button import DbDeviceButton
from DeviceServer.models.db_device_led import DbDeviceLed
from DeviceServer.models.db_device_port import DbDevicePort
from DeviceServer.models.db_device_temperature_port import DbDeviceTemperaturePort
from DeviceServer.models.db_led_state import DbLedState
from DeviceServer.models.db_port_state import DbPortState
from DeviceServer.models.device import Device
from DeviceServer.models.device_button import DeviceButton
from DeviceServer.models.device_led import DeviceLed
from DeviceServer.models.device_port import DevicePort
from DeviceServer.models.device_rx_buffer import DeviceRxBuffer
from DeviceServer.models.device_temperature_port import DeviceTemperaturePort
from DeviceServer.models.device_tx_buffer import DeviceTxBuffer
from DeviceServer.models.get_attenuator_state200_response import GetAttenuatorState200Response
from DeviceServer.models.get_devices_led200_response import GetDevicesLed200Response
from DeviceServer.models.get_firmware_version200_response import GetFirmwareVersion200Response
from DeviceServer.models.host_config import HostConfig
from DeviceServer.models.port_state import PortState
from DeviceServer.models.temp_range import TempRange
from DeviceServer.models.temperature import Temperature
